Method: Digicert::Findable#find_by_object
- Defined in:
- lib/digicert/findable.rb
#find_by_object(object) ⇒ Object
Find by object
This find_by_object interface works more likely a wrapper around find interface, it expects the object to response to the id method. Then it delegates object initialization behavior to the find interface.
29 30 31 |
# File 'lib/digicert/findable.rb', line 29 def find_by_object(object) find(object.id) end |